Expetator
=========

Starting an experiment
----------------------

.. automodule:: expetator.experiment
	:members: run_experiment

Interaction with the platform
-----------------------------

.. autoclass:: expetator.experiment.Executor
   :members:
   :undoc-members:

   	    

